@@ -1,6 +1,6 @@
 package Redis::LeaderBoard;
 use 5.008001;
-our $VERSION = "1.00";
+our $VERSION = "1.01";
 use Mouse;
 use Mouse::Util::TypeConstraints;
 use Redis::LeaderBoard::Member;
@@ -102,15 +102,7 @@ sub get_rank_with_score {
     my $score = $self->get_score($member);
     return unless defined $score;
 
-    my $method = $self->is_asc ? 'zrank' : 'zrevrank';
-    my $rank  = $self->get_sorted_order($member);
-
-    return (1, $score) if $rank == 0; # zero origin
-
-    my ($min, $max) = $self->is_asc ? ('-inf', "($score") : ("($score", 'inf');
-    my $above_count = $self->member_count($min, $max);
-    $rank = $above_count + 1;
-
+    my $rank = $self->get_rank_by_score($score);
     ($rank, $score);
 }
 
@@ -135,7 +127,7 @@ sub rankings {
     my ($current_rank, $current_target_score, $same_score_members);
     while (my ($member, $score) = splice @$members_with_scores, 0, 2) {
         if (!$current_rank) {
-            $current_rank         = $self->get_rank($member);
+            $current_rank         = $self->get_rank_by_score($score);
             $same_score_members   = $offset - $current_rank + 2;
             $current_target_score = $score;
         }
@@ -157,6 +149,13 @@ sub rankings {
     \@rankings;
 }
 
+sub get_rank_by_score {
+    my ($self, $score) = @_;
+
+    my ($min, $max) = $self->is_asc ? ('-inf', "($score") : ("($score", 'inf');
+    return $self->member_count($min, $max) + 1;
+}
+
 sub member_count {
     my ($self, $from, $to) = @_;
 
@@ -205,8 +204,6 @@ Redis::LeaderBoard is for providing leader board by using Redis's sorted set.
 z(rev)?rank of Redis 2.8 or older doesn't consider same scores.
 This module resolve it.
 
-B<THIS IS A ALPHA QUALITY RELEASE. API MAY CHANGE WITHOUT NOTICE>.
-
 =head1 INTERFACE
 
 =head2 Constructor
